from setuptools import setup

setup(name='Gaussian_Bolinomial_distributions',
      version='0.1',
      description='Gaussian and bolinomial distributions',
      packages=['Gaussian_Bolinomial_distributions'],
      zip_safe=False)
